predict classifies a new set of observations from a
previously built classifier. This function will provide either
a vector of new classes, class probability estimates, or both.
"predict"(object, newdata = NULL, type = c("class", "prob", "both","F"),n.iter=NULL,...)maboost.maboost call (n.iter< iter)predict.rpart and predict.rpart and predict.C5.0.
summary.maboost,print.maboost,
update.maboost