update.maboost:
Add more trees to an maboost object
Description
maboost.update updates the maboost object to have additional trees given a new number of
iterations.
Usage
"update"(object, x, y, test.x, test.y = NULL, n.iter, ...)
Arguments
object
object generated by the function maboost.
test.x
x testing data (optional)
test.y
the true labeling for this testing data (optional)
n.iter
new number of iterations, must be provided and n.iter>iter
...
other arguments not used by this function.
Value
updated maboost object.